==> haskell-th-compat-0.1.5-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-compat
version:              0.1.5
visibility:           public
id:                   th-compat-0.1.5-D8U1XeDLfbDJysYkekrFIp
key:                  th-compat-0.1.5-D8U1XeDLfbDJysYkekrFIp
license:              BSD-3-Clause
copyright:            (C) 2020 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
homepage:             https://github.com/haskell-compat/th-compat
synopsis:             Backward- (and forward-)compatible Quote and Code types
description:
    This package defines a "Language.Haskell.TH.Syntax.Compat"
    module, which backports the @Quote@ and @Code@ types to
    work across a wide range of @template-haskell@ versions.
    The @makeRelativeToProject@ utility is also backported.
    On recent versions of @template-haskell@ (2.17.0.0 or
    later), this module simply reexports definitions
    from "Language.Haskell.TH.Syntax". Refer to the Haddocks
    for "Language.Haskell.TH.Syntax.Compat" for examples of
    how to use this module.

category:             Text
abi:                  4d770258813d6d3443f9f4d71134d737
exposed:              True
exposed-modules:      Language.Haskell.TH.Syntax.Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/th-compat-0.1.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/th-compat-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-compat
hs-libraries:         HSth-compat-0.1.5-D8U1XeDLfbDJysYkekrFIp
depends:
    base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2
    template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-th-compat/html/th-compat.haddock
haddock-html:         /usr/share/doc/haskell-th-compat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-compat-0.1.5-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-compat
version:              0.1.5
visibility:           public
id:                   th-compat-0.1.5-6fZvIr7qyVF5MKyQjfHwhQ
key:                  th-compat-0.1.5-6fZvIr7qyVF5MKyQjfHwhQ
license:              BSD-3-Clause
copyright:            (C) 2020 Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ryan Scott
homepage:             https://github.com/haskell-compat/th-compat
synopsis:             Backward- (and forward-)compatible Quote and Code types
description:
    This package defines a "Language.Haskell.TH.Syntax.Compat"
    module, which backports the @Quote@ and @Code@ types to
    work across a wide range of @template-haskell@ versions.
    The @makeRelativeToProject@ utility is also backported.
    On recent versions of @template-haskell@ (2.17.0.0 or
    later), this module simply reexports definitions
    from "Language.Haskell.TH.Syntax". Refer to the Haddocks
    for "Language.Haskell.TH.Syntax.Compat" for examples of
    how to use this module.

category:             Text
abi:                  addf073714ffdff2a0d01ee162691ab9
exposed:              True
exposed-modules:      Language.Haskell.TH.Syntax.Compat
import-dirs:          /usr/lib/ghc-9.2.8/site-local/th-compat-0.1.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/th-compat-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-compat
hs-libraries:         HSth-compat-0.1.5-6fZvIr7qyVF5MKyQjfHwhQ
depends:
    base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2
    template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-th-compat/html/th-compat.haddock
haddock-html:         /usr/share/doc/haskell-th-compat/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
